==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Input/gme/translations/gme_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="39"/>
        <source>GME Plugin</source>
        <translation>Módulo GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="42"/>
        <source>Game Music Files</source>
        <translation>Archivos de Game Music</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="106"/>
        <source>About GME Audio Plugin</source>
        <translation>Acerca del Módulo de Audio GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="107"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation>Módulo de Audio GME de Qmmp</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="108"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation>Este módulo usa la biblioteca Game_Music_Emu para reproducir archivos de música</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="109"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>GME Plugin Settings</source>
        <translation>Configuración de Módulo GME</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Fadeout length:</source>
        <translation>Longitud de salida con fundido:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Enable fadeout</source>
        <translation>Habilitar salida con fundido</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.6.tar.bz2: qmmp-2.2.6/src/plugins/Input/gme/translations/gme_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="37"/>
        <source>GME Plugin</source>
        <translation>Módulo GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="42"/>
        <source>Game Music Files</source>
        <translation>Archivos de Game Music</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="101"/>
        <source>About GME Audio Plugin</source>
        <translation>Acerca del Módulo de Audio GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="102"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation>Módulo de Audio GME de Qmmp</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="103"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation>Este módulo usa la biblioteca Game_Music_Emu para reproducir archivos de música</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="104"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>GmeSettingsDialog</name>
    <message>
        <location filename="../gmesettingsdialog.ui" line="14"/>
        <source>GME Plugin Settings</source>
        <translation>Configuración de Módulo GME</translation>
    </message>
    <message>
        <location filename="../gmesettingsdialog.ui" line="34"/>
        <source>Fadeout length:</source>
        <translation>Longitud de salida con fundido:</translation>
    </message>
    <message>
        <location filename="../gmesettingsdialog.ui" line="44"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../gmesettingsdialog.ui" line="57"/>
        <source>Enable fadeout</source>
        <translation>Habilitar salida con fundido</translation>
    </message>
</context>
</TS>
